import Joi from 'joi'
import Package from './package'

const plugin = {
    multiple: true,
    pkg: {
        name: Package.name,
        version: Package.version
    },
    async register(server, options) {
        server.route({
            method: 'GET',
            path: '/kittens',
            handler(request) {
                return 'hello'
            },
            options: {
                description: 'List all kittens',
                notes: 'Returns a list of all kittens. The kittens are returned sorted by creation date, with the most recently created kitten appearing first.'
            }
        })

        server.route({
            method: 'GET',
            path: '/kittens/{ID}',
            handler(request) {
                return 'goodbye'
            },
            options: {
                description: 'Retrieve a kitten',
                notes: 'Retrieves the details of an existing kitten. Supply the unique kitten ID from either a kitten creation request or the kitten list, and it will return the corresponding kitten information.',
                validate: {
                    params: {
                        id: Joi.string()
                            .required()
                            .description('The identifier of the kitten to be retrieved.')
                    }
                }
            }
        })

        server.route({
            method: 'DELETE',
            path: '/kittens/{ID}',
            handler(request) {
                return 'goodbye'
            },
            options: {
                description: 'Delete a kitten',
                validate: {
                    params: {
                        id: Joi.string()
                            .required()
                            .description('The identifier of the kitten to be deleted.')
                    }
                }
            }
        })
    }
}

export default plugin
